@@ -16,6 +16,7 @@ from . import tools
 from . import colors
 from . import pandastools
 from . import ta
+from . import themes
 
 from .helper import _printer as help
 from .plotlytools import *
@@ -31,8 +32,17 @@ from .version import __version__
 
 try:
 	if get_config_file()['offline']:
-		go_offline()
+		go_offline(True)
 	else:
 		go_online()
 except:
 	pass
+
+# User Defined Colors
+
+try: 
+	colors.cnames = utils.merge_dict(colors.cnames,auth.get_user_colors())
+	colors._scales_names = utils.merge_dict(colors._scales_names,auth.get_user_scales())
+	themes.THEMES = utils.merge_dict(themes.THEMES,auth.get_user_themes())
+except:
+	pass
\ No newline at end of file
